<?php
/**
 * The main function behind the Settings page
 */
function wp_cpl_itg_settings_page() {
    /**
     * If the user has got the permission
     */
    if (!current_user_can('manage_options'))  {
        wp_die( __('You do not have sufficient permissions to access this page.') );
    }
    
    /**
     * Update options on POST
     */
    if($_SERVER['REQUEST_METHOD'] == 'POST') {
        $wp_cpl_op = array(
            'wp_cpl_use_def_css' => (bool) $_POST['wp-cpl-def-css'],
            'wp_cpl_thumb_size' => (int) $_POST['wp-cpl-thumb-size'],
            'wp_cpl_css_theme' => (int) $_POST['wp-cpl-css-theme']
        );
        
        update_option('wp-cpl-itg-op', $wp_cpl_op);
        
        ?>
        <div class="updated fade">
            <?php _e('Options Saved', 'wp-cat-list-itg'); ?>
        </div>
        <?php
    }
    
    /**
     * Get the options for future use
     */
    extract(get_option('wp-cpl-itg-op'));
    ?>
    <script type="text/javascript">
        jQuery(document).ready(function($) {
            $('.postbox').children('h3, .handlediv').click(function(){
                $(this).siblings('.inside').toggle();
            });
        }); 
    </script>
    <div class="wrap">
        <h2>Configure the Global options of WP CPL</h2>
        <p><small>Plugin developed by <a href="http://www.swashata.me">Swashata</a> | <a href="http://www.intechgrity.com">InTechgrity</a></small></p>
        <div id="poststuff" class="metabox-holder">
        <div class="meta-box-sortables">
            <div class="wp-cpl-wrap">
                <div class="wp-cpl-wrap-left">
                    <!--
                    <div class="postbox">
                        <div class="handlediv" title="<?php _e('Click to Toggle', 'wp-cat-list-itg'); ?>"><br /></div>
                        <h3 class="hndle"></h3>
                        <div class="inside">
                            
                        </div>
                    </div>
                    -->
                    <div class="postbox">
                        <div class="handlediv" title="<?php _e('Click to Toggle', 'wp-cat-list-itg'); ?>"><br /></div>
                        <h3 class="hndle"><span class="wp-cpl-admin-op"><span></span><?php _e('Global Options', 'wp-cat-list-itg'); ?></span></h3>
                        <div class="inside">
                            <form action="<?php echo $_SERVER['REQUEST_URI']; ?>" method="post">
                                <ul>
                                    <li>
                                        <label for="wp-cpl-def-css"><?php _e('Use Default CSS? &raquo;', 'wp-cat-list-itg'); ?></label>
                                        <input type="checkbox" id="wp-cpl-def-css" name="wp-cpl-def-css"<?php if(true == $wp_cpl_use_def_css) { ?> checked="checked"<?php } ?> />
                                    </li>
                                    <li>
                                        <span class="description">
                                            <?php _e('This will add the default CSS file to your theme. Make sure your theme has something like <code>wp_head()</code> inside the header.php file.', 'wp-cat-list-itg'); ?>
                                        </span>
                                    </li>
                                    <li>
                                        <label for="wp-cpl-thumb-size"><?php _e('Thumbnail Size: &raquo;', 'wp-cat-list-itg'); ?></label>
                                        <input type="text" class="" id="wp-cpl-thumb-size" name="wp-cpl-thumb-size" value="<?php echo $wp_cpl_thumb_size; ?>" />
                                    </li>
                                    <li>
                                        <label for="wp-cpl-css-theme"><?php _e('Select Theme: &raquo;', 'wp-cat-list-itg'); ?></label>
                                        <select name="wp-cpl-css-theme" id="wp-cpl-css-theme">
                                            <option value="0"<?php if(0 == $wp_cpl_css_theme) echo ' selected="selected"'; ?>><?php _e('Light Theme', 'wp-cat-list-itg'); ?></option>
                                            <option value="1"<?php if(1 == $wp_cpl_css_theme) echo ' selected="selected"'; ?>><?php _e('Dark Theme', 'wp-cat-list-itg'); ?></option>
                                        </select>
                                    </li>
                                    <li>
                                        <input class="button-primary" type="submit" value="<?php _e('Save Options', 'wp-cat-list-itg'); ?>" />
                                    </li>
                                </ul>
                            </form>
                        </div>
                    </div>
                    
                    <div class="postbox">
                        <div class="handlediv" title="<?php _e('Click to Toggle', 'wp-cat-list-itg'); ?>"><br /></div>
                        <h3 class="hndle"><span class="wp-cpl-admin-ins"><span></span><?php _e('Usage Instruction', 'wp-cat-list-itg'); ?></span></h3>
                        <div class="inside">
                            <p>
                                <?php _e('The Wordpress Category Post Lists is a powerful Wordpress Widget plugin, giving you complete control over how your posts are displayed on your sidebar filtered by categories', 'wp-cat-list-itg'); ?>
                                <br />
                                <?php _e('The only options you need to set here are the global thumbnail sizes and whether you want to use the default CSS file provided with this plugin.', 'wp-cat-list-itg'); ?>
                                <br />
                                <?php _e('Everything else can be set from the widgets options page. Here are all the information about the options, and the available parameters', 'wp-cat-list-itg'); ?>
                            </p>
                            <h4>Widget Options</h4>
                            <table class="widefat">
                                <thead>
                                    <tr>
                                        <th scope="col"><?php _e('Option Name', 'wp-cat-list-itg'); ?></th>
                                        <th scope="col"><?php _e('Description', 'wp-cat-list-itg'); ?></th>
                                        <th scope="col"><?php _e('Options Parameter', 'wp-cat-list-itg'); ?></th>
                                        <th scope="col"><?php _e('Default value', 'wp-cat-list-itg'); ?></th>
                                        <th scope="col"><?php _e('Example', 'wp-cat-list-itg'); ?></th>
                                    </tr>
                                </thead>
                                <tfoot>
                                    <tr>
                                        <th scope="col"><?php _e('Option Name', 'wp-cat-list-itg'); ?></th>
                                        <th scope="col"><?php _e('Description', 'wp-cat-list-itg'); ?></th>
                                        <th scope="col"><?php _e('Options Parameter', 'wp-cat-list-itg'); ?></th>
                                        <th scope="col"><?php _e('Default value', 'wp-cat-list-itg'); ?></th>
                                        <th scope="col"><?php _e('Example', 'wp-cat-list-itg'); ?></th>
                                    </tr>
                                </tfoot>
                                <tbody>
                                    <tr>
                                        <td colspan="5" align="right"><strong>
                                            <?php _e('Basic Options', 'wp-cat-list-itg'); ?>
                                        </strong></td>
                                    </tr>
                                    <tr>
                                        <td><?php _e('Title', 'wp-cat-list-itg'); ?></td>
                                        <td>
                                            <?php _e('The Title of the widget. This will be displayed over the top of each widget', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('It has the following options paramter. You can insert them on the title and it will get replaced by the corresponding values', 'wp-cat-list-itg'); ?>
                                            <ul>
                                                <li>
                                                    <strong>%widget_num%</strong> :
                                                    <?php _e('The number of posts you want to display', 'wp-cat-list-itg'); ?>
                                                </li>
                                                <li>
                                                    <strong>%cat_count%</strong> :
                                                    <?php _e('The total number of posts the category has', 'wp-cat-list-itg'); ?>
                                                </li>
                                                <li>
                                                    <strong>%cat_name%</strong> :
                                                    <?php _e('The category name', 'wp-cat-list-itg'); ?>
                                                </li>
                                            </ul>
                                        </td>
                                        <td>
                                            Featuring Top %widget_num%/%cat_count% of %cat_name%
                                        </td>
                                        <td>
                                            <?php _e('Be creative and form your own', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Category', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('The category you want to chose. Select one from the list', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Show Link', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('If ticked this will show a <strong>Read More</strong> link at the end of the widget. This will link to the category', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('By default this is ticked', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Number of Posts', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('The total number of posts that would be shown on the widget. This excludes the number of sticky posts.', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            10
                                        </td>
                                        <td>
                                            <?php _e('What ever you can imagine', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Comment count', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Whether you want to show comment count beside every posts.', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Unticked. Not shown by default', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Show Feed', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('If ticked a link will be placed before the title to the feed of the category.', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Ticked. Attempts to show the feed', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Feed Image or Text', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('The anchor text or image link which would be hyperlinked to the category feed', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('If you enter a valid image URL then the image would be shown. Else it will use the value as anchor text.', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Say your Enter a image URL http://yousite.com/path/to/image.png or simply a Text [Syndicate]', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Show Thumbnail &amp; Thumb Class', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Whether you want to show thumbnail beside every post, and if showing then the css class applied to the thumbnail', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('The Structure of the thumbnail is as follows', 'wp-cat-list-itg'); ?>
                                            <p>
                                                <pre style="max-width: 200px; overflow: auto;"><code>
&lt;span class=&quot;wp-thumb-overlay&quot;&gt;
        &lt;span class=&quot;thumb_lay or userclass&quot;&gt;
                &lt;img width=&quot;40&quot; height=&quot;40&quot; title=&quot;Title&quot; alt=&quot;alt&quot; class=&quot;attachment-wp-cpl-post-thumb wp-post-image&quot; src=&quot;path/to/img.jpg&quot; /&gt;
        &lt;/span&gt;
&lt;/span&gt;   
                                                </code></pre>
                                            </p>
                                        </td>
                                        <td>
                                            thumb_lay
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Sorting', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Here you have two options. Sort Order and Sort Using. You can choose from a number of available options for the Sort Using, and make it ascending or descending', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Sort Using has ID, title, date, comment or random options.', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Date -> Ascendng', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td colspan="5" align="right">
                                            <strong>
                                                <?php _e('Advanced Options. Just Click to Toggle button to reveal', 'wp-cat-list-itg'); ?>
                                            </strong>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('List Style', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('How the HTML list is formed. This is basically the HTML nesting', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Unordered list is the basic ul li type listing. You can select Custom Style to insert your own HTML tags before/after the list/links', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('HTML Unordered List', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Widget Style', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('The CSS class applied to the widget', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td colspan="3">
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Before/After List/Link', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('The HTML tag before the whole Widget List', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <p>
                                            <?php _e('Before List supports only one parameter.', 'wp-cat-list-itg'); ?><br />
                                            <strong>%widget_class%</strong> :
                                            <?php _e('Gets replaced by system generated widget class and your own widget class', 'wp-cat-list-itg'); ?>
                                            </p>
                                            <p>
                                                <?php _e('Similarly Before Link supports one paramter', 'wp-cat-list-itg'); ?>
                                                <strong>%list_class%</strong> :
                                                <?php _e('Gets replaced by system generated list class. This is needed if you are applying custom class to sticky post or alternate list css classes', 'wp-cpl-list-itg'); ?>
                                            </p>
                                        </td>
                                        <td>
                                            <ul class="wp-cpl-admin-ul">
                                                <li>
                                                    <strong><?php _e('Before List', 'wp-cat-list-itg'); ?> :<code>&lt;ul class="%widget_class%"&gt;</code></strong>
                                                </li>
                                                <li>
                                                    <strong><?php _e('After List', 'wp-cat-list-itg'); ?> : <code>&lt;/ul&gt;</code></strong>
                                                </li>
                                                <li>
                                                    <strong><?php _e('Before Link', 'wp-cat-list-itg'); ?> : <code>&lt;li class="%list_class%"&gt;</code></strong>
                                                </li>
                                                <li>
                                                    <strong><?php _e('After Link', 'wp-cat-list-itg'); ?> : <code>&lt;/li&gt;</code></strong>
                                                </li>
                                            </ul>
                                        </td>
                                        <td>
                                            <ul class="wp-cpl-admin-ul">
                                                <li>
                                                    <strong><?php _e('Before List', 'wp-cat-list-itg'); ?> :<code>&lt;div class="my_class %widget_class%"&gt;</code></strong>
                                                </li>
                                                <li>
                                                    <strong><?php _e('After List', 'wp-cat-list-itg'); ?> : <code>&lt;/div&gt;</code></strong>
                                                </li>
                                                <li>
                                                    <strong><?php _e('Before Link', 'wp-cat-list-itg'); ?> : <code>&lt;p class="my_post class %list_class%"&gt;</code></strong>
                                                </li>
                                                <li>
                                                    <strong><?php _e('After Link', 'wp-cat-list-itg'); ?> : <code>&lt;/p&gt;</code></strong>
                                                </li>
                                            </ul>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Exclude Posts', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Comma Seperated values of IDs of posts to exclude', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('The following ID format will work', 'wp-cat-list-itg'); ?>
                                            <br /><br />
                                            <code>12, 34,65 75,12 ,45</code>
                                        </td>
                                        <td colspan="2">
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Sticky Posts', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td colspan="4">
                                            <?php _e('Same as Exclude Posts. Only the posts will become sticky. This will not very whether they belong to the selected category or not. They will be placed before the normal list and CSS class wp-cpl-sticky will be applied to them', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Open in', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Whether to open in the current tab or new tab', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Basically <code>_blank</code> or <code>_self</code> will be added to the anchor tag', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Current Tab', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td>
                                            <?php _e('Alternate List CSS', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('Applies Alternate Listing CSS classes to the list HTML tag.', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td>
                                            <?php _e('wp-cpl-odd or wp-cpl-even CSS classes will be added accordingly', 'wp-cat-list-itg'); ?>
                                        </td>
                                        <td colspan="2">
                                            <?php _e('N/A', 'wp-cat-list-itg'); ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                        </div>
                    </div>
                    
                    <div class="postbox">
                        <div class="handlediv" title="<?php _e('Click to Toggle', 'wp-cat-list-itg'); ?>"><br /></div>
                        <h3 class="hndle"><span class="wp-cpl-admin-faq"><span></span><?php _e('FAQs', 'wp-cat-list-itg'); ?></span></h3>
                        <div class="inside">
                            <p>Will be added when it comes out of the RC.</p>
                        </div>
                    </div>
                </div>
                <div class="wp-cpl-wrap-right">
                    <div class="postbox">
                        <div class="handlediv" title="<?php _e('Click to Toggle', 'wp-cat-list-itg'); ?>"><br /></div>
                        <h3 class="hndle"><span class="wp-cpl-admin-donate"><span></span><?php _e('Support Us', 'wp-cat-list-itg'); ?></span></h3>
                        <div class="inside">
                            <p>
                                <?php _e('There\'s a lot of effort behind the development of this plugin. Please support us by doing any of the following :) ', 'wp-cat-list-itg'); ?>
                                <ul class="wp-cpl-admin-ul">
                                    <li><?php _e('Buy us some beer!', 'wp-cat-list-itg'); ?></li>
                                    <li><?php _e('Write about this plugin on your blog.', 'wp-cat-list-itg'); ?></li>
                                    <li><?php _e('Help us by translating the plugin.', 'wp-cat-list-itg'); ?></li>
                                </ul>
                            </p>
                            <p>
                                <?php
                                _e('If you like to donate, then please use the link below', 'wp-cat-list-itg');
                                ?>
                            </p>
                            <a class="don_but" href="http://www.intechgrity.com/about/buy-us-some-beer/">
                                <img src="<?php echo plugins_url('css/images/donate.png', WP_CPL_ABSPATH); ?>" />
                            </a>
                        </div>
                    </div>
                    
                    <div class="postbox">
                        <div class="handlediv" title="<?php _e('Click to Toggle', 'wp-cat-list-itg'); ?>"><br /></div>
                        <h3 class="hndle"><span class="wp-cpl-admin-itg"><span></span><?php _e('InTechgrity', 'wp-cat-list-itg'); ?></span></h3>
                        <div class="inside">
                            <script src="http://feeds.feedburner.com/greentechspot?format=sigpro" type="text/javascript" ></script><noscript><p>Subscribe to RSS headline updates from: <a href="http://feeds.feedburner.com/greentechspot"></a><br/>Powered by FeedBurner</p> </noscript>
                        <p><a href="http://feedburner.google.com/fb/a/mailverify?uri=greentechspot&amp;loc=en_US">Subscribe to inTechgrity by Email</a></p>
                        </div>
                    </div>
                    
                    <div class="postbox">
                        <div class="handlediv" title="<?php _e('Click to Toggle', 'wp-cat-list-itg'); ?>"><br /></div>
                        <h3 class="hndle"><span class="wp-cpl-admin-proj"><span></span><?php _e('Projects', 'wp-cat-list-itg'); ?></span></h3>
                        <div class="inside">
                            <script src="http://feeds.feedburner.com/IntechgrityProjects?format=sigpro" type="text/javascript" ></script><noscript><p>Subscribe to RSS headline updates from: <a href="http://feeds.feedburner.com/IntechgrityProjects"></a><br/>Powered by FeedBurner</p> </noscript>
                        </div>
                    </div>
                    
                    <div class="postbox">
                        <div class="handlediv" title="<?php _e('Click to Toggle', 'wp-cat-list-itg'); ?>"><br /></div>
                        <h3 class="hndle"><span class="wp-cpl-admin-spon"><span></span><?php _e('Sponsors', 'wp-cat-list-itg'); ?></span></h3>
                        <div class="inside">
                            <a href="http://www.elegantthemes.com/affiliates/idevaffiliate.php?id=5226_0_1_11" target="_blank"><img border="0" src="http://www.elegantthemes.com/affiliates/banners/234x120.gif" width="234" height="120"></a>
                            &nbsp;
                            <a href="http://www.flexihostnz.com/aff.php?aff=016"><img src="http://www.flexihostnz.com/banners/125x125-2.gif" width="125" height="125" border="0"></a>
                        </div>
                    </div>
                    
                </div>
            </div>
        </div>
        </div>
    </div>
    <?php
}
/**
 * The thumb size generator
 * Add the thumbnail support only if not already supported by theme.
 * Checks to see if add_theme_support exists
 * when add_theme_support('post-thumbnail') is called the get_the_post_thumbnail is activated
 * So, we will also see if the function get_the_post_thumbnail does not exists
 */
function wp_cpl_rpt_activation_hook() {
    if(function_exists('add_theme_support') && !function_exists('get_the_post_thumbnail')) {
        add_theme_support( 'post-thumbnails' );
    }
    
    if(function_exists('add_theme_support') && function_exists('add_image_size')) {
        extract(get_option('wp-cpl-itg-op'));
        add_image_size('wp-cpl-post-thumb', $wp_cpl_thumb_size, $wp_cpl_thumb_size, true);
    }
}
add_action('after_setup_theme', 'wp_cpl_rpt_activation_hook');

/**
 * The admin menu hook
 */
function wp_cpl_admin_init() {
    //Load the menu
    $wp_cpl_admin = add_options_page(__('WP Category Post List', 'wp-cat-list-itg'), __('Category Posts (WP-CPL)', 'wp-cat-list-itg'), 'manage_options', 'wp_cpl_itg_page', 'wp_cpl_itg_settings_page');
    
    //Add the stylesheet
    add_action('admin_print_styles-' . $wp_cpl_admin, 'wp_cpl_admin_styles');
}

/**
 * The stylesheet Loader
 */
function wp_cpl_admin_styles() {
    wp_enqueue_style('wp-cpl-admin-css', plugins_url('css/admin.css', WP_CPL_ABSPATH));
}

/**
 * Hook them up
 */
add_action('admin_menu', 'wp_cpl_admin_init');

/**
 * The CSS theme HOOK
 */
function wp_cpl_widget_css_hook() {
    extract(get_option('wp-cpl-itg-op'));
/*
 Ref
 @ignore
$wp_cpl_op = array(
    'wp_cpl_use_def_css' => (bool) $_POST['wp-cpl-def-css'],
    'wp_cpl_thumb_size' => (int) $_POST['wp-cpl-thumb-size'],
    'wp_cpl_css_theme' => (int) $_POST['wp-cpl-css-theme']
);

update_option('wp-cpl-itg-op', $wp_cpl_op);
*/
    /**
     * Switch through the option
     * Only if user has selected to use the CSS templates
     */
    if(true == $wp_cpl_use_def_css) {
        
        /** Get the path */
        $wp_cpl_css_path = '';
        switch($wp_cpl_css_theme) {
            default :
            case 0 :
                $wp_cpl_css_path = plugins_url('css/wp-cat-list-light.css', WP_CPL_ABSPATH);
                break;
            case 1 :
                $wp_cpl_css_path = plugins_url('css/wp-cat-list-dark.css', WP_CPL_ABSPATH);
        }
        
        /** Enqueue it */
        wp_enqueue_style('wp-cpl-css-theme', $wp_cpl_css_path);
    }
    
}
/**
 * Hook it
 */
add_action('wp_print_styles', 'wp_cpl_widget_css_hook');