<?php
/*
Plugin Name: WP Category Post List Widget
Plugin URI: http://www.intechgrity.com/
Description: Lists down Posts filtered by category. You can show thumbnail, modify the HTML structure of the widget and do almost whatever you want. Access it from the Widgets option under the Appearance
Version: 0.9.0.rc
Author: Swashata
Author URI: http://www.swashata.me/
License: GPL2
*/

/*  Copyright 2010  Swashata Ghosh  (email : swashata4u@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/** Load Text Domain For Translations */
load_plugin_textdomain('wp-cat-list-itg', null, dirname(__FILE__) . '/translations');

/**
 * The activation hook
 * Does 2 thing
 * Check PHP 5 on activation and upgrade settings (Hat tip - Ozh, YOURLS plugin)
 * add default options
 */
register_activation_hook(__FILE__, 'wp_cat_list_itg_activate_plugin');
function wp_cat_list_itg_activate_plugin() {
	/**
	 * Check to see if PHP 5. Thanks Gautam <http://gaut.am>
	 */
	if (version_compare(PHP_VERSION, '5.0.0', '<')) {
		deactivate_plugins(basename(__FILE__));
		wp_die(__('WP Category List Wordpress plugin requires PHP5. Sorry!', 'wp-cat-list-itg'));
		return;
	}
	/**
	 * Set the default options
	 */
	$wp_cpl_op = array(
		'wp_cpl_use_def_css' => true,
		'wp_cpl_thumb_size' => 50,
		'wp_cpl_css_theme' => 0
	);
	add_option('wp-cpl-itg-op', $wp_cpl_op, '', 'no');
}

/**
 * The deactivation hook
 * Deletes the wp-cpl-op
 */
register_deactivation_hook(__FILE__, 'wp_cat_list_itg_deactivate_plugin');
function wp_cat_list_itg_deactivate_plugin() {
	delete_option('wp-cpl-itg-op');
}

/**
 * Provide a settings option from the plugin page
 * (Hat Tip - Event Espresso Lite - Event Registration and Management)
 */
function wp_cpl_plugin_settings_op($links, $file) {
	static $this_plugin;
	if ( ! $this_plugin ) $this_plugin = plugin_basename(__FILE__);
	
	if ( $file == $this_plugin ){
		$org_settings_link = '<a href="admin.php?page=wp_cpl_itg_page">' . __('Settings') . '</a>';
		$events_link = '<a href="widgets.php">' . __('Widgets') . '</a>';
		array_unshift( $links, $org_settings_link, $events_link ); // before other links
	}
	return $links;
}
add_filter('plugin_action_links', 'wp_cpl_plugin_settings_op', 10, 2);


/**
 * Store the dirname
 */
define('WP_CPL_ABSPATH', __FILE__);

/**
 * The Widget Class
 * @package Wordpress
 * @subpackage Widget
 * @since 1.0.0
 * @author Swashata <swashata4u@gmail.com>
 * @todo Complete the Widget Backend form [DONE]
 * @todo Add jQuery to widget backend form [DONE]
 * @todo Make the main widget with cachable output [DONE]
 */
class WP_Category_Post_List_itg extends WP_Widget {
    
    /**
     * The constructor function
     */
    function WP_Category_Post_List_itg() {
        
        /** Widget option */
        $widget_ops = array('description' => 'List down your posts by category. With Thumbnail and more!!');
        
        /** Control Options */
        $control_ops = array('width' => 500);
	
	/** Do this **/
	parent::WP_Widget( false, $name = 'WP Category Post List', $widget_ops, $control_ops );
    }
    
    /**
     * The main Widget
     * All the magic Happens here
     */
    
    function widget($args, $instance) {
	/** Extact default things */
	extract($args);
	
	/** Now lets start the main output */
	/**
	 * We are using wp_cache_get, wp_cache_set and wp_cache_delete for better caching of the complex query results
	 * Hat Tip: Most Commented Widget <http://plugins.trac.wordpress.org/browser/most-commented/trunk/most-commented.php?rev=248712#L56>
	 */
	if(!$output = wp_cache_get($widget_id)) {
		/**
		 * Initiate the output
		 * and the post_output
		 */
		$output = '';
		$post_output = '';
		/**
		 * Set the before post list HTML
		 */
		$before_link = (true == $instance['list_style'])? '<li class="%list_class%">' : $instance['before_link'];
		$after_link = (true == $instance['list_style'])? '</li>' : $instance['after_link'];
		/** Calculate stick posts and excluded posts */
		$wp_cpl_sticky = wp_parse_id_list($instance['sticky_post']);
		$wp_cpl_exclude = wp_parse_id_list($instance['exclude_post']);
		
		/** First get the Sticky posts */
		if(count($wp_cpl_sticky)) {
			$wp_cpl_post_sticky = get_posts(
				array(
					'post__in' => $wp_cpl_sticky
				)
			);
			
			/** Loop through the sticky posts */
			foreach($wp_cpl_post_sticky as $post) {
				/** Initiate the post list widget HTML */
				$default_class = 'wp-cpl-sticky';
				$post_output .= str_ireplace('%list_class%', "{$default_class}", $before_link);
				
				/** is thumbnail? */
				$post_output .= (((true == $instance['is_thumb']) && ('' != ($wp_cpl_post_thumb = get_the_post_thumbnail($post->ID, 'wp-cpl-post-thumb'))))? '<span class="wp-thumb-overlay"><span class="' . $instance['thumb_class'] . '">' . $wp_cpl_post_thumb . '</span></span>' : '');
				
				/** Add up the actual permalink and post title */
				$post_output .= '<a href="' . get_permalink($post->ID) . '" title="' . __('Permalink to: ', 'wp-cat-list-itg') . $post->post_title . '" target="' . ((false == $instance['open_in'])? '_blank' : '_self') . '">' . $post->post_title . '</a>';
				
				/** Show comments? */
				$post_output .= ((true == $instance['show_comments'])? ' <span class="wp-cpl-comment">' . $post->comment_count . __(' Comments', 'wp-cat-list-itg') . '</span>' : '');
				
				/** Done. Now close the Widget */
				$post_output .= $after_link . "\n";
			}
		}
		
		/** Set the shortcut array for the order type **/
		//1 => 'Date', 2 => 'Comment', 3 => 'ID', 4 => 'Title', 5 => 'Random'
		$wp_cpl_sort_array = array(
			1 => 'date',
			2 => 'comment_count',
			3 => 'ID',
			4 => 'title',
			5 => 'rand'
		);
		
		/**
		 * Merge the sticky and exclude posts array
		 * So no duplicate post is shown
		 */
		$wp_cpl_exclude = array_merge($wp_cpl_sticky, $wp_cpl_exclude);
		$wp_cpl_exclude = array_unique($wp_cpl_exclude);
		
		/** Set the arguments of the get_posts function */
		$get_posts_args = array(
			'cat' => $instance['cat_id'],
			'numberposts' => $instance['list_num'],
			'orderby' => $wp_cpl_sort_array[$instance['sort_using']],
			'order' => ((true == $instance['sort_order'])? 'ASC' : 'DESC'),
			'post__not_in' => $wp_cpl_exclude
		);
		
		/** Actually get the post */
		$wp_cpl_posts = get_posts($get_posts_args);
		
		/** Loop through the posts */
		$i = 0;
		foreach($wp_cpl_posts as $post) {
			
			/** Initiate the post list widget HTML */
			$default_class = ((true == $instance['alternate_list_css'])? (($i%2 == 0)? 'wp-cpl wp-cpl-even' : 'wp-cpl wp-cpl-odd') : 'wp-cpl');
			$post_output .= str_ireplace('%list_class%', "{$default_class}", $before_link);
			
			/** is thumbnail? */
			$post_output .= (((true == $instance['is_thumb']) && ('' != ($wp_cpl_post_thumb = get_the_post_thumbnail($post->ID, 'wp-cpl-post-thumb'))))? '<span class="wp-thumb-overlay"><span class="' . $instance['thumb_class'] . '">' . $wp_cpl_post_thumb . '</span></span>' : '');
			
			/** Add up the actual permalink and post title */
			$post_output .= '<a href="' . get_permalink($post->ID) . '" title="' . __('Permalink to: ', 'wp-cat-list-itg') . $post->post_title . '" target="' . ((false == $instance['open_in'])? '_blank' : '_self') . '">' . $post->post_title . '</a>';
			
			/** Show comments? */
			$post_output .= ((true == $instance['show_comments'])? ' <span class="wp-cpl-comment">' . $post->comment_count . __(' Comments', 'wp-cat-list-itg') . '</span>' : '');
			
			/** Done. Now close the Widget */
			$post_output .= $after_link . "\n";
			$i++;
		}
		
		/**
		 * Done the Loop
		 * Now add the main widget data to the output
		 */
		
		/** The themes before widget */
		$output .= $before_widget;
		
		/** The title with parameters */
		//%widget_num%/%cat_count% of %cat_name%
		$wp_cpl_cat_info = get_category($instance['cat_id']);
		
		$title = str_ireplace(array('%widget_num%', '%cat_count%', '%cat_name%'), array($i, $wp_cpl_cat_info->count, $wp_cpl_cat_info->name), $instance['title']);
		$title = apply_filters('the_title', $title);
		
		/** Check to see if feed syndication is active */
		if(true == $instance['show_feed'] && '' != $instance['feed_img_text']) {
			$wp_cpl_cat_feed = get_category_feed_link($instance['cat_id']);
			
			/**
			 * If the submitted text validates to be an image URL then use <img />
			 * Else plain text
			 */
			if(preg_match('!http://[a-z0-9\-\.\/]+\.(?:jpe?g|png|gif)!Ui', $instance['feed_img_text'])) {
				$title = '<a href="' . $wp_cpl_cat_feed . '"><img src="' . $instance['feed_img_text'] . '" /></a> ' . $title;
			}
			else {
				$title = '<a href="' . $wp_cpl_cat_feed . '">' . $instance['feed_img_text'] . '</a> ' . $title;
			}
		}
		$output .= $before_title . $title . $after_title;
		
		/**
		 * Set the USER made before, after widget
		 */
		if(false == $instance['list_style']) {
			$before_main_widget = (('' != $instance['before_main_widget'])? $instance['before_main_widget'] : '<ul class="%widget_class%">');
			$after_main_widget = (('' != $instance['after_main_widget'])? $instance['after_main_widget'] : '</ul>');
		}
		else {
			$before_main_widget = '<ul class="%widget_class%">';
			$after_main_widget = '</ul>';
		}
		
		/**
		 * Now apply the class to the widget
		 */
		$wp_cpl_widget_class = (('' != $instance['widget_class'])? 'wp-cpl-widget '. $instance['widget_class'] : 'wp-cpl-widget');
		$before_main_widget = str_ireplace('%widget_class%', $wp_cpl_widget_class, $before_main_widget);
		
		/**
		 * Wrap the $post_output with the before and after user widget html
		 * for the $output we have upto the title
		 */
		$post_output = $before_main_widget . $post_output . $after_main_widget;
		/**
		 * Now add the read more thing
		 */
		if(true == $instance['show_link']) {
			$post_output .= '<p class="wp-cpl-read-more"><a href="' . get_category_link($wp_cpl_cat_info->ID) . '" title="' . $wp_cpl_cat_info->description . '">' . __('Read More &raquo;', 'wp-cat-list-itg') . '</a></p>';
		}
		
		/**
		 * Done all the dynamic things
		 * Now add the post_output to output and close the theme's widget
		 */
		$output .= $post_output;
		$output .= $after_widget;
		
		/**
		 * Cache it for future use
		 */
		wp_cache_set($widget_id, $output, '', 18);
		
	}
	echo $output;
    }
    /**
     * The save options function
     */
    function update($new_instance, $old_instance) {
	/** Set the previous value */
	$instance = $old_instance;
	
	/** Extract the current values for shortcut */
	extract($new_instance);
	
	/** Sanitize the inputs properly */
	$instance['title']		= strip_tags($title);
	$instance['cat_id']		= (int) $cat_id;
	$instance['show_link']		= (bool) $show_link;
	$instance['show_feed']		= (bool) $show_feed;
	$instance['feed_img_text']	= strip_tags($feed_img_text);
	$instance['is_thumb']		= (bool) $is_thumb;
	$instance['thumb_class']	= strip_tags($thumb_class);
	$instance['list_num']		= (int) $list_num;
	$instance['widget_class']	= strip_tags($widget_class);
	$instance['list_style']		= (bool) $list_style;
	$instance['show_comments']	= (bool) $show_comments;
	$instance['sort_using']		= (int) $sort_using;
	$instance['sort_order']		= (bool) $sort_order;
	$instance['before_main_widget']	= esc_html($before_main_widget);
	$instance['after_main_widget']	= esc_html($after_main_widget);
	$instance['before_link']	= esc_html($before_link);
	$instance['after_link']		= esc_html($after_link);
	$instance['exclude_post']	= strip_tags($exclude_post);
	$instance['sticky_post']	= strip_tags($sticky_post);
	$instance['open_in']		= (bool) $open_in;
	$instance['alternate_list_css']	= (bool) $alternate_list_css;
	
	/** Delete the previous cache */
	wp_cache_delete($this->id);
	
	/** Check for any error */
	
	/** Return it */
	return $instance;
    }
    
    /**
     * The backend form
     * @param string $title The title of the widget
     * @param int $cat_id The category id to list
     * @param bool $show_link Link to the category
     * @param bool $show_feed Link to the Feed of the category
     * @param string $feed_img_text URL to the feed image or Link text
     * @param bool $is_thumb Whether or not to display thumbnail
     * @param string $thumb_class The CSS Class applied to the thumbnail
     * @param int $list_num The number of posts to list down
     * @param string $widget_class The CSS class of the widget <div class="blah"></div>
     * @param bool $list_style Whether or not ul li list style or custom
     * @param bool $show_comments Whether or not to show comment count
     * @param int $sort_using 1=>Date 2=>Comment 3=>ID 4=>Title 5=> Random
     * @param bool $sort_order TURE=>ASC FALSE=>DESC
     * @param string $before_main_widget HTML or whatever before the link list starts
     * @param string $before_link HTML before the <a> tag
     * @param strong $after_link HTML after the </a> tag
     * @param string $after_main_widget HTML or whatever after the link list ends
     * @param string $exclude_post CSV of posts to exclude
     * @param string $sticky_post CSV of posts to make sticky
     * @param bool $highlight_sticky to add custom class to sticky post X NOT USING
     * @param string $sticky_class Class added to sticky posts X NOT USING. As I thought giving a default class can save the user using custom CSS selector and also can save me by excluding a couple of options :)
     * @param bool $open_in New tab(false) or current tab(true)
     * @param bool $alternate_list_css YES(TRUE) NO(FALSE)
     * @param string $error If there exists any error
     */
    function form($instance) {
	/** The translator domain */
	$wp_cat_list_itg_tans = 'wp-cat-list-itg';
	
	/** Register the instance */
	$instance = wp_parse_args((array) $instance, array (
	    'title'			=> 'Featuring Top %widget_num%/%cat_count% of %cat_name%',
	    'cat_id'			=> NULL,
	    'show_link'			=> false,
	    'show_feed'			=> true,
	    'feed_img_text'		=> '',
	    'is_thumb'			=> true,
	    'thumb_class'		=> 'thumb_lay',
	    'list_num'			=> 10,
	    'widget_class'		=> '',
	    'list_style'		=> true,
	    'show_comments'		=> false,
	    'sort_using'		=> 1,
	    'sort_order'		=> true,
	    'before_main_widget'	=> '',
	    'before_link'		=> '',
	    'after_link'		=> '',
	    'after_main_widget'		=> '',
	    'exclude_post'		=> '',
	    'sticky_post'		=> '',
	    'open_in'			=> true,
	    'alternate_list_css'	=> true,
	    'error'			=> false
	));
	
	/** Parse the value */
	extract($instance);
	
	/** Output the form */
	?>
	<!-- Basic options -->
	<h3><?php _e('Basic Options &raquo;', $wp_cat_list_itg_tans); ?></h3>
	<?php
	if($error) {
	    ?>
	<p><strong><?php _e('The Following Error Occured', $wp_cat_list_itg_tans); ?></strong></p>
	<?php echo $error; ?>
	    <?php
	}
	?>
	<p> <!-- Title -->
	    <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title of Widget: ', $wp_cat_list_itg_tans); ?></label>
	    <input type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" class="widefat" />
	</p>
	<p> <!-- Category | Show Link -->
	    <label for="<?php echo $this->get_field_id('cat_id'); ?>"><?php _e('Category: ', $wp_cat_list_itg_tans); ?></label>
	    <select id="<?php echo $this->get_field_id('cat_id'); ?>" name="<?php echo $this->get_field_name('cat_id'); ?>">
		<?php
		$cat_lists = get_categories(array('orderby' => 'name', 'order' => 'ASC'));
		foreach($cat_lists as $cat_list) {
		    ?>
		    <option value="<?php echo $cat_list->term_id; ?>"<?php if($cat_list->term_id == $cat_id) { ?> selected="selected"<?php } ?>><?php echo $cat_list->name.' ('.$cat_list->count.')'; ?></option>
		    <?php
		}
		?>
	    </select>
	    &nbsp;&nbsp;|&nbsp;&nbsp;
	    <label for="<?php echo $this->get_field_id('show_link'); ?>"><?php _e('Show Link? &raquo;', $wp_cat_list_itg_tans); ?></label>
	    <input type="checkbox" name="<?php echo $this->get_field_name('show_link'); ?>" id="<?php echo $this->get_field_id('show_link'); ?>"<?php if(true == $show_link) { ?> checked="checked"<?php } ?> />
	</p>
	<p> <!-- Number | Comment -->
	    <label for="<?php echo $this->get_field_id('list_num'); ?>"><?php _e('Number of Posts to show: &raquo;', $wp_cat_list_itg_tans); ?></label>
	    <input type="text" name="<?php echo $this->get_field_name('list_num'); ?>" id="<?php echo $this->get_field_id('list_num'); ?>" class="small-text code" value="<?php echo $list_num; ?>" />
	    <br />
	    <label for="<?php echo $this->get_field_id('show_comments'); ?>"><?php _e('Show Comment count? &raquo; ', $wp_cat_list_itg_tans); ?></label>
	    <input type="checkbox" name="<?php echo $this->get_field_name('show_comments'); ?>" id="<?php echo $this->get_field_id('show_comments'); ?>"<?php if(true == $show_comments) { ?> checked="checked"<?php } ?> />
	</p>
	<p> <!-- Show Feed | Feed image link -->
	    <label for="<?php echo $this->get_field_id('show_feed'); ?>"><?php _e('Show Feed? &raquo;', $wp_cat_list_itg_tans); ?></label>
	    <input type="checkbox" name="<?php echo $this->get_field_name('show_feed'); ?>" id="<?php echo $this->get_field_id('show_feed'); ?>"<?php if(true == $show_feed) { ?> checked="checked"<?php } ?> />
	    &nbsp;&nbsp;|&nbsp;&nbsp;
	    <label for="<?php echo $this->get_field_id('feed_img_text'); ?>"><?php _e('Feed Image or Text &raquo;', $wp_cat_list_itg_tans); ?></label>
	    <input type="text" name="<?php echo $this->get_field_name('feed_img_text'); ?>" id="<?php echo $this->get_field_id('feed_img_text'); ?>" value="<?php echo $feed_img_text; ?>" />
	    <br />
	    <span class="description">
		<?php _e('Works only if Show Feed is checked. Enter URL to the image (http://www.path.to/img/url.png) to show image or just enter simple text. It will automatically understand whether u want image or text', $wp_cat_list_itg_tans); ?>
	    </span>
	</p>
	<p> <!-- is thumb | Thumb class -->
	    <label for="<?php echo $this->get_field_id('is_thumb'); ?>"><?php _e('Show Thumbnail? &raquo; ', $wp_cat_list_itg_tans); ?></label>
	    <input type="checkbox" name="<?php echo $this->get_field_name('is_thumb'); ?>" id="<?php echo $this->get_field_id('is_thumb'); ?>"<?php if(true == $is_thumb) { ?> checked="checked"<?php } ?> />
	    &nbsp;&nbsp;|&nbsp;&nbsp;
	    <label for="<?php echo $this->get_field_id('thumb_class'); ?>"><?php _e('Thumbnail Class: &raquo;', $wp_cat_list_itg_tans); ?></label>
	    <input type="text" name="<?php echo $this->get_field_name('thumb_class'); ?>" id="<?php echo $this->get_field_id('thumb_class'); ?>" value="<?php echo $thumb_class; ?>" />
	    <span class="description"><?php _e('Optional', $wp_cat_list_itg_tans); ?></span>
	</p>
	<p><!-- Sort Using | Sort Order -->
	    <label for="<?php echo $this->get_field_id('sort_using'); ?>"><?php _e('Sort Using: &raquo; ', $wp_cat_list_itg_tans); ?></label>
	    <select name="<?php echo $this->get_field_name('sort_using'); ?>" id="<?php echo $this->get_field_id('sort_using'); ?>">
		<?php
		$sort_using_ops = array(1 => 'Date', 2 => 'Comment', 3 => 'ID', 4 => 'Title', 5 => 'Random');
		foreach($sort_using_ops as $sort_using_op_key => $sort_using_op_value) {
		    ?>
		    <option value="<?php echo $sort_using_op_key; ?>"<?php if($sort_using == $sort_using_op_key) { ?> selected="selected"<?php } ?>><?php _e($sort_using_op_value, $wp_cat_list_itg_tans); ?></option>
		    <?php
		}
		?>
	    </select>
	    &nbsp;&nbsp;|&nbsp;&nbsp;
	    <label for="<?php echo $this->get_field_id('sort_order'); ?>"><?php _e('Sort Order &raquo;', $wp_cat_list_itg_tans); ?></label>
	    <select name="<?php echo $this->get_field_name('sort_order'); ?>" id="<?php echo $this->get_field_id('sort_order'); ?>">
		<option value="0"<?php if(false == $sort_order) echo ' selected="selected"'; ?>><?php _e('Descending', $wp_cat_list_itg_tans); ?></option>
		<option value="1"<?php if(true == $sort_order) echo ' selected="selected"'; ?>><?php _e('Ascending', $wp_cat_list_itg_tans); ?></option>
	    </select>
	</p>
	<!-- Advanced Options -->
	<h3><?php _e('Advance Options &raquo;', $wp_cat_list_itg_tans); ?></h3>
	<div>
	<a class="button-secondary wp-cpl-itg-but" href="#"><?php _e('Toggle Options', $wp_cat_list_itg_tans); ?></a>
	<div class="wp-cpl-itg-advop" style="display: none;">
		<br class="clear clearfix" style="height: 10px" />
		<p> <!-- list style | Widget Class -->
		    <label for="<?php echo $this->get_field_id('list_style'); ?>"><?php _e('List Style: &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <select name="<?php echo $this->get_field_name('list_style'); ?>" id="<?php echo $this->get_field_id('list_style'); ?>">
			<option value="0"<?php if(false == $list_style) echo ' selected="selected"'; ?>>Custom Style</option>
			<option value="1"<?php if(true == $list_style) echo ' selected="selected"'; ?>>HTML unordered list</option>
		    </select>
		    &nbsp;&nbsp;|&nbsp;&nbsp;
		    <label for="<?php echo $this->get_field_id('widget_class'); ?>"><?php _e('Widget Class: &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <input type="text" name="<?php echo $this->get_field_name('widget_class'); ?>" id="<?php echo $this->get_field_id('widget_class'); ?>" value="<?php echo $widget_class; ?>" />
		    <br />
		    <span class="description"><?php _e('These classes will be added to the <code>&lt;ul class="your_class"&gt;</code> if using the default listing style. Else you should use options parameters for constructing your custom HTML structure. For example &lt;div class="your_class %widget_class%"&gt;. The %widget_class% will be replaced by the default class by the widget. For more read the FAQ from the plugins Settings page.', $wp_cat_list_itg_tans); ?></span>
		</p>
		<p> <!-- Before main widget | After main widget -->
		    <label for="<?php echo $this->get_field_id('before_main_widget'); ?>"><?php _e('Before List: &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <input type="text" name="<?php echo $this->get_field_name('before_main_widget'); ?>" id="<?php echo $this->get_field_id('before_main_widget'); ?>" value="<?php echo $before_main_widget; ?>" />
		    &nbsp;&nbsp;|&nbsp;&nbsp;
		    <label for="<?php echo $this->get_field_id('after_main_widget'); ?>"><?php _e('After List: &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <input type="text" value="<?php echo $after_main_widget; ?>" name="<?php echo $this->get_field_name('after_main_widget'); ?>" id="<?php echo $this->get_field_id('after_main_widget'); ?>" />
		</p>
		<p> <!-- Before Link | After Link -->
		    <label for="<?php echo $this->get_field_id('before_link'); ?>"><?php _e('Before Link: &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <input type="text" name="<?php echo $this->get_field_name('before_link'); ?>" id="<?php echo $this->get_field_id('before_link'); ?>" value="<?php echo $before_link; ?>" />
		    &nbsp;&nbsp;|&nbsp;&nbsp;
		    <label for="<?php echo $this->get_field_id('after_link'); ?>"><?php _e('After Link: &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <input type="text" name="<?php echo $this->get_field_name('after_link'); ?>" id="<?php echo $this->get_field_id('after_link'); ?>" value="<?php echo $after_link; ?>" />
		    <br />
		    <span class="description">
			<?php
			_e('Before link and after will appear before and after the &lt;a href="your_link.html"&gt;anchor_text&lt;/a&gt;. <br />Similarly, before list and after list will wrap the whole link list', $wp_cat_list_itg_tans);
			?>
		    </span>
		</p>
		<p> <!-- exclude post and sticky post -->
		    <label for="<?php echo $this->get_field_id('exclude_post'); ?>"><?php _e('Exclude: &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <input type="text" name="<?php echo $this->get_field_name('exclude_post'); ?>" id="<?php echo $this->get_field_id('exclude_post'); ?>" value="<?php echo $exclude_post; ?>" />
		    <label for="<?php echo $this->get_field_id('sticky_post'); ?>"><?php _e('Sticky: &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <input type="text" name="<?php echo $this->get_field_name('sticky_post'); ?>" id="<?php echo $this->get_field_id('sticky_post'); ?>" value="<?php echo $sticky_post; ?>" />
		    <br />
		    <span class="description">
			    <?php _e('Comma seperated values of post ids. Eg: 34,56,98,13,54 etc. No white space no trailing comma', $wp_cat_list_itg_tans); ?>
		    </span>
		</p>
		<p> <!-- Open in option -->
		    <label for="<?php echo $this->get_field_id('open_in'); ?>"><?php _e('Open in? &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <select name="<?php echo $this->get_field_name('open_in'); ?>" id="<?php echo $this->get_field_id('open_in'); ?>">
			    <option value="0"<?php if(false == $open_in) echo ' selected="selected"'; ?>>New Tab or Window</option>
			    <option value="1"<?php if(true == $open_in) echo ' selected="selected"'; ?>>Current Tab or Window</option>
		    </select>
		</p>
		<p> <!-- Alternate listing style -->
		    <label for="<?php echo $this->get_field_id('alternate_list_css'); ?>"><?php _e('Apply alternate style? &raquo;', $wp_cat_list_itg_tans); ?></label>
		    <input type="checkbox" name="<?php echo $this->get_field_name('alternate_list_css'); ?>" id="<?php echo $this->get_field_id('alternate_list_css'); ?>"<?php if(true == $alternate_list_css) echo ' checked="checked"'; ?> />
		    <br />
		    <span class="description">
			    <?php _e('If checked, then the classes wp-cpl-odd or wp-cpl-even will be added to the respective odd or even items of the list', $wp_cat_list_itg_tans); ?>
		    </span>
		</p>
	</div>
	</div>
	<?php
    }
}

add_action( 'widgets_init', create_function( '', 'return register_widget( "WP_Category_Post_List_itg" );' ) );

/**
 * Add the jQuery code to the widgets.php menu
 * It loads the Advanced Options button toggler
 */
function wp_cpl_itg_adminaction_insert_js() {
	wp_enqueue_script('wp-cpl-itg-js', plugins_url('js/admin-jq.js', __FILE__), array('jquery'));
}
add_action('admin_print_scripts-widgets.php', 'wp_cpl_itg_adminaction_insert_js');

/**
 * Include the Settings page
 */
include_once(plugin_dir_path(__FILE__) . 'includes/wp-cpl-settings.php');